@@ -4,8 +4,6 @@
 
 import functools
 import importlib
-import operator
-import os
 import warnings
 from functools import lru_cache
 from importlib.util import find_spec
@@ -110,14 +108,17 @@ class RequirementCache:
                 self.message = f"{ex.__class__.__name__}: {ex}. HINT: Try running `pip install -U {self.requirement!r}`"
 
     def __bool__(self) -> bool:
+        """Format as bool."""
         self._check_requirement()
         return self.available
 
     def __str__(self) -> str:
+        """Format as string."""
         self._check_requirement()
         return self.message
 
     def __repr__(self) -> str:
+        """Format as string."""
         return self.__str__()
 
 
@@ -146,19 +147,22 @@ class ModuleAvailableCache:
             self.message = f"Module not found: {self.module!r}. HINT: Try running `pip install -U {self.module}`"
 
     def __bool__(self) -> bool:
+        """Format as bool."""
         self._check_requirement()
         return self.available
 
     def __str__(self) -> str:
+        """Format as string."""
         self._check_requirement()
         return self.message
 
     def __repr__(self) -> str:
+        """Format as string."""
         return self.__str__()
 
 
 def get_dependency_min_version_spec(package_name: str, dependency_name: str) -> str:
-    """Returns the minimum version specifier of a dependency of a package.
+    """Return the minimum version specifier of a dependency of a package.
 
     >>> get_dependency_min_version_spec("pytorch-lightning==1.8.0", "jsonargparse")
     '>=4.12.0'
@@ -189,12 +193,14 @@ class LazyModule(ModuleType):
         self._callback = callback
 
     def __getattr__(self, item: str) -> Any:
+        """Overwrite attribute access to attribute."""
         if self._module is None:
             self._import_module()
 
         return getattr(self._module, item)
 
     def __dir__(self) -> List[str]:
+        """Overwrite attribute access for dictionary."""
         if self._module is None:
             self._import_module()
 
@@ -214,16 +220,20 @@ class LazyModule(ModuleType):
 
 
 def lazy_import(module_name: str, callback: Optional[Callable] = None) -> LazyModule:
-    """Returns a proxy module object that will lazily import the given module the first time it is used. Example usage::
+    """Return a proxy module object that will lazily import the given module the first time it is used.
+
+    Example usage:
 
         # Lazy version of `import tensorflow as tf`
         tf = lazy_import("tensorflow")
         # Other commands
         # Now the module is loaded
         tf.__version__
+
     Args:
         module_name: the fully-qualified module name to import
         callback: a callback function to call before importing the module
+
     Returns:
         a proxy module object that will be lazily imported when first used
     """
@@ -231,10 +241,9 @@ def lazy_import(module_name: str, callback: Optional[Callable] = None) -> LazyMo
 
 
 def requires(*module_path: str, raise_exception: bool = True) -> Callable:
-    """Wrapper for early import failure with some nice exception message.
+    """Wrap early import failure with some nice exception message.
 
     Example:
-
         >>> @requires("libpath", raise_exception=bool(int(os.getenv("LIGHTING_TESTING", "0"))))
         ... def my_cwd():
         ...     from pathlib import Path
